@@ -1,13 +1,14 @@
 package Parse::Number::EN;
 
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.06'; # VERSION
+
 # TODO: make it OO and customize thousand sep & decimal point
 
 use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '0.05'; # VERSION
-
 use Exporter::Lite;
 our @EXPORT_OK = qw($Pat parse_number_en);
 
@@ -57,7 +58,7 @@ sub parse_number_en {
 }
 
 1;
-# ABSTRACT: Pattern to match number
+# ABSTRACT: Parse number from English text
 
 __END__
 
@@ -67,11 +68,11 @@ __END__
 
 =head1 NAME
 
-Parse::Number::EN - Pattern to match number
+Parse::Number::EN - Parse number from English text
 
 =head1 VERSION
 
-This document describes version 0.05 of Parse::Number::EN (from Perl distribution Parse-Number-EN), released on 2014-10-03.
+This document describes version 0.06 of Parse::Number::EN (from Perl distribution Parse-Number-EN), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -113,9 +114,7 @@ The input text that contains number.
 
 =back
 
-Return value:
-
- (any)
+Return value:  (any)
 
 =head1 VARIABLES
 
@@ -145,7 +144,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Parse-Numb
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Parse-Number-EN>.
+Source repository is at L<https://github.com/perlancar/perl-Parse-Number-EN>.
 
 =head1 BUGS
 
@@ -161,7 +160,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
